'use strict';

var JSON = require('json3');
var integration = require('@segment/analytics.js-integration');
var useHttps = require('use-https');

/**
 * Expose `TvSquared` integration.
 */

var TvSquared = module.exports = integration('TV Squared')
  // NOTE(ndhoule): `tv2track.js` introduces the JSON2 global
  .global('JSON2')
  .global('_tvq')
  .option('brandId', '')
  .option('hostname', '')
  .tag('<script src="//{{ hostname }}/piwik/tv2track.js">');

/**
 * Initialize TV Squared.
 *
 * @param {Facade} page
 *
 */

TvSquared.prototype.initialize = function() {
  window._tvq = window._tvq || [];
  var url = useHttps() ? 'https://' : 'http://';
  url += this.options.hostname + '/piwik/';
  window._tvq.push(['setSiteId', this.options.brandId]);
  window._tvq.push(['setTrackerUrl', url + 'piwik.php']);

  this.load();
  this.ready();
};

/**
 * Has the TV Squared library been loaded yet?
 *
 * @return {Boolean}
 */

TvSquared.prototype.loaded = function() {
  return !!window._tvq;
};

/**
 * Page
 *
 * @param {Facade} page
 */

TvSquared.prototype.page = function() {
  window._tvq.push(['trackPageView']);
};

/**
 * Track an event.
 *
 * @param {Facade} track
 */

TvSquared.prototype.track = function(track) {
  var event = track.event();
  var session = { user: track.userId() || track.anonymousId() || '' };
  var action = {
    rev: track.revenue(),
    prod: track.proxy('properties.productType'),
    id: track.orderId(),
    promo: track.proxy('properties.promo')
  };

  window._tvq.push([
    function() {
      this.setCustomVariable(5, 'session', JSON.stringify(session), 'visit');
    }
  ]);
  window._tvq.push([
    function() {
      this.setCustomVariable(5, event, JSON.stringify(action), 'page');
    }
  ]);
  window._tvq.push(['trackPageView']);
};
